@@ -39,8 +39,8 @@ class Plantsim:
         Suppresses the start of the 3D view.
     _show_msg_box : bool
         Whether to show a message box.
-    _relative_path : str
-        Relative model path.
+    _network_path : str
+        Network path.
     _event_thread
         Event thread object.
     _event_handler : PlantSimEvents
@@ -53,7 +53,7 @@ class Plantsim:
         Path to the loaded model.
     _running : str
         Simulation status.
-    _simulation_error : dict | None
+    _simulation_error : Optional[dict]
         Simulation error details.
     _simulation_finished_event : threading.Event
         Event triggered when the simulation finishes.
@@ -76,7 +76,7 @@ class Plantsim:
     _license: Union[PlantsimLicense, str] = None
     _suppress_3d: bool = None
     _show_msg_box: bool = None
-    _relative_path: str = None
+    _network_path: str = None
     _event_thread = None
     _event_handler: PlantSimEvents = None
     _event_polling_interval: float = 0.05
@@ -85,7 +85,7 @@ class Plantsim:
     _model_loaded: bool = False
     _model_path: str = None
     _running: str = False
-    _simulation_error: dict | None = None
+    _simulation_error: Optional[dict] = None
     _simulation_finished_event: threading.Event = None
 
     # Callbacks
@@ -244,15 +244,15 @@ class Plantsim:
         if self._instance:
             self.quit()
 
-    def set_model(
+    def set_network(
         self,
         path: PlantsimPath,
-        install_error_handler: bool = False,
         set_event_controller: bool = False,
+        install_error_handler: bool = False,
     ) -> None:
-        """Set the active model."""
-        self._relative_path = path
-        self._instance.SetPathContext(str(self._relative_path))
+        """Set the active network."""
+        self._network_path = path
+        self._instance.SetPathContext(str(self._network_path))
 
         if install_error_handler:
             self.install_error_handler(path)
@@ -306,7 +306,7 @@ class Plantsim:
         if self._user_simulation_finished_cb:
             self._user_simulation_finished_cb()
 
-    def register_on_simulation_finished(self, callback: Callable[[], None] | None):
+    def register_on_simulation_finished(self, callback: Optional[Callable[[], None]]):
         """Set Callback for OnSimulationFinished Event."""
         self._user_simulation_finished_cb = callback
 
@@ -341,18 +341,20 @@ class Plantsim:
             return False
         return True
 
-    def register_on_simtalk_message(self, callback: Callable[[str], None] | None):
+    def register_on_simtalk_message(self, callback: Optional[Callable[[str], None]]):
         """Set Callback for OnSimTalkMessage Event."""
         self._user_simtalk_msg_cb = callback
 
-    def register_on_fire_simtalk_message(self, callback: Callable[[str], None] | None):
+    def register_on_fire_simtalk_message(
+        self, callback: Optional[Callable[[str], None]]
+    ):
         """Set Callback for FireSimTalkMessage Event."""
         self._user_fire_simtalk_msg_cb = callback
         if self._event_handler:
             self._event_handler.on_fire_simtalk_message = callback
 
     def register_on_simulation_error(
-        self, callback: Callable[[SimulationException], None] | None
+        self, callback: Optional[Callable[[SimulationException], None]]
     ):
         self._user_simulation_error_cb = callback
 
@@ -404,10 +406,8 @@ class Plantsim:
         """
         if path:
             self._event_controller = path
-        elif self._relative_path:
-            self._event_controller = PlantsimPath(
-                self._relative_path, "EventController"
-            )
+        elif self._network_path:
+            self._event_controller = PlantsimPath(self._network_path, "EventController")
 
     def execute_sim_talk(self, source_code: str, *parameters: any) -> any:
         """
@@ -649,6 +649,11 @@ class Plantsim:
         """Attribute holding the path to current model file"""
         return self._model_path
 
+    @property
+    def network_path(self) -> Union[str, None]:
+        """Attribute holding the current active network path"""
+        return self._network_path
+
     @property
     def visible(self) -> bool:
         """Attribute holding true, when the instance is visible, false, when it's not"""
